@@ -8,7 +8,7 @@ our @ISA = qw( Exporter );
 
 our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns Process );
 
-our $VERSION = "1.3";
+our $VERSION = "1.4";
 
 
 sub new
@@ -53,7 +53,7 @@ sub LoadArgs
     {
         SWITCH_ARGS:
         {
-            if ( $arg =~ /^-(.*)/ )
+            if ( $arg =~ /^-(.+)/ )
             {
                 SWITCH_OPTS:
                 {
@@ -66,13 +66,13 @@ sub LoadArgs
                     if ( $1 eq "ra" )   { $fgcolor = undef; $bold = undef; $bgcolor = undef;
                                           last SWITCH_OPTS }
                     if ( $1 eq "b" )    { $bold = 1; last SWITCH_OPTS }
-                    if ( ( my $orig = $1 ) =~ /\d{1,3}(?=\.1)/ )
+                    if ( ( my $orig = $1 ) =~ /^\d{1,3}(?=\.1)$/ )
                                         { $bgcolor = substr $orig, $-[ 0 ], $+[ 0 ] - $-[ 0 ];
                                           last SWITCH_OPTS }
-                    if ( ( my $orig = $1 ) =~ /\d{1,3}(?=\.0)?/ )
+                    if ( ( my $orig = $1 ) =~ /^\d{1,3}(?=\.0)?$/ )
                                         { $fgcolor = substr $orig, $-[ 0 ], $+[ 0 ] - $-[ 0 ];
                                           last SWITCH_OPTS }
-                    print __PACKAGE__, " : Warning: unknown option '-$1'\n";
+                    print __PACKAGE__, " : WARNING: unknown option '$arg'\n";
                 }
                 $lastPatternOmitted = 1;
                 last SWITCH_ARGS;
@@ -341,7 +341,7 @@ A. Radkov, E<lt>alexey.radkov@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2015 by A. Radkov.
+Copyright (C) 2008-2016 by A. Radkov.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
